@@ -59,6 +59,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "erlang",
     "golang",
     "haskell",
+    "haxe",
     "helm",
     "java",
     "julia",
@@ -67,6 +68,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "nim",
     "nodejs",
     "ocaml",
+    "opa",
     "perl",
     "php",
     "pulumi",
@@ -85,6 +87,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "zig",
     // ↑ Toolchain version modules ↑
     "buf",
+    "guix_shell",
     "nix_shell",
     "conda",
     "meson",
@@ -106,6 +109,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "time",
     "status",
     "container",
+    "os",
     "shell",
     "character",
 ];
@@ -116,7 +120,7 @@ impl Default for StarshipRootConfig {
         Self {
             schema: "https://starship.rs/config-schema.json".to_string(),
             format: "$all".to_string(),
-            right_format: "".to_string(),
+            right_format: String::new(),
             continuation_prompt: "[∙](bright-black) ".to_string(),
             scan_timeout: 30,
             command_timeout: 500,
