@@ -41,7 +41,9 @@ pub const ALL_MODULES: &[&str] = &[
     "git_state",
     "git_status",
     "golang",
+    "guix_shell",
     "haskell",
+    "haxe",
     "helm",
     "hg_branch",
     "hostname",
@@ -59,7 +61,9 @@ pub const ALL_MODULES: &[&str] = &[
     "nix_shell",
     "nodejs",
     "ocaml",
+    "opa",
     "openstack",
+    "os",
     "package",
     "perl",
     "php",
